@@ -21,16 +21,27 @@ Sjis-JA - Source code filter to escape ShiftJIS (Japanese document)
 
        no Sjis; ͗pł܂B
 
-    R}hvvgňȉ̂悤Ɏs
-      perl     ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl55   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl56   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl58   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl510  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl512  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl514  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl516  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl64   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+    R}hvvgňȉ̂ꂩŎs
+      perl      ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl5     ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl55    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl56    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl58    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl510   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl512   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl514   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl516   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl64    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      aperl58   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      aperl510  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      aperl512  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      aperl514  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      aperl516  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      sperl58   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      sperl510  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      sperl512  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      sperl514  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      sperl516  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
 
       ? * găChJ[h̎w肪ł܂
       ' ` ' găNH[g邱Ƃł܂
@@ -53,11 +64,18 @@ Sjis-JA - Source code filter to escape ShiftJIS (Japanese document)
       Sjis::index(...);
       Sjis::rindex(...);
       CORE::chop(...);
+      CORE::ord(...);
+      CORE::reverse(...);
+      CORE::index(...);
+      CORE::rindex(...);
 
    Perl5.6 G~[V(perl5.005̏ꍇ)
       use warnings;
       use warnings::register;
 
+   Perl5.16 G~[V
+      use feature qw(fc);
+
    ȉ̓_~[֐Ƃ
       utf8::upgrade(...);
       utf8::downgrade(...);
@@ -177,9 +195,6 @@ GXP[v_قȂ܂B
    make test
    make install
 
-   VXe strict.pm Ȃꍇ͕t strict.pm_  strict.pm Ƀl[
-   ĎgpĂB
-
 =head1 CXg[@(makegȂꍇ)
 
    perl pMakefile.pl         --- pMakefile.pl  pmake.bat 𐶐܂
@@ -196,9 +211,6 @@ GXP[v_قȂ܂B
    perl516  pmake.bat install --- perl5.016 ɃCXg[܂
    perl64   pmake.bat install --- perl64    ɃCXg[܂
 
-   VXe strict.pm Ȃꍇ͕t strict.pm_  strict.pm Ƀl[
-   ĎgpĂB
-
    pmake.bat dist             --- CPAN zzppbP[W܂
    pmake.bat ptar.bat         --- ptar.bat 쐬܂
 
@@ -208,6 +220,7 @@ GXP[v_قȂ܂B
    Char/Esjis.pm         --- Sjis.pm ̃^C[`
    Sjis.pm               --- Char/Sjis.pm ̕ʖ(@\͓ł)
    Esjis.pm              --- Char/Esjis.pm ̕ʖ(@\͓ł)
+   perl5.bat             --- ϐ PATH ̐ݒȂ perl5    TĎs
    perl55.bat            --- ϐ PATH ̐ݒȂ perl5.5  TĎs
    perl56.bat            --- ϐ PATH ̐ݒȂ perl5.6  TĎs
    perl58.bat            --- ϐ PATH ̐ݒȂ perl5.8  TĎs
@@ -216,9 +229,21 @@ GXP[v_قȂ܂B
    perl514.bat           --- ϐ PATH ̐ݒȂ perl5.14 TĎs
    perl516.bat           --- ϐ PATH ̐ݒȂ perl5.16 TĎs
    perl64.bat            --- ϐ PATH ̐ݒȂ perl64   TĎs
+   aperl58.bat           --- ϐ PATH ̐ݒȂ ActivePerl 5.8  TĎs
+   aperl510.bat          --- ϐ PATH ̐ݒȂ ActivePerl 5.10 TĎs
+   aperl512.bat          --- ϐ PATH ̐ݒȂ ActivePerl 5.12 TĎs
+   aperl514.bat          --- ϐ PATH ̐ݒȂ ActivePerl 5.14 TĎs
+   aperl516.bat          --- ϐ PATH ̐ݒȂ ActivePerl 5.16 TĎs
+   sperl58.bat           --- ϐ PATH ̐ݒȂ Strawberry Perl 5.8  TĎs
+   sperl510.bat          --- ϐ PATH ̐ݒȂ Strawberry Perl 5.10 TĎs
+   sperl512.bat          --- ϐ PATH ̐ݒȂ Strawberry Perl 5.12 TĎs
+   sperl514.bat          --- ϐ PATH ̐ݒȂ Strawberry Perl 5.14 TĎs
+   sperl516.bat          --- ϐ PATH ̐ݒȂ Strawberry Perl 5.16 TĎs
+
    strict.pm_            --- _~[ strict.pm
    warnings.pm_          --- warnings.pm ̊ȈՔ
    warnings/register.pm_ --- warnings/register.pm ̊ȈՔ
+   feature.pm_           --- _~[ feature.pm
 
 =head1 GXP[vɂʌ݊̊m
 
@@ -383,7 +408,7 @@ Sjis.pm  /i Cq̑ Esjis::ignorecase() ̌ďo܂B
   \S            @{Esjis::eS}
   \W            @{Esjis::eW}
   \h            [\x09\x20]
-  \v            [\x0C\x0A\x0D]
+  \v            [\x0A\x0B\x0C\x0D]
   \H            @{Esjis::eH}
   \V            @{Esjis::eV}
   \C            [\x00-\xFF]
@@ -452,7 +477,7 @@ t@C Esjis.pm ̒ňȉ̂悤ɒ`Ă܂B
   @{Esjis::eS}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x0A\x0C\x0D\x20])}
   @{Esjis::eW}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC0-9A-Z_a-z])}
   @{Esjis::eH}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x20])}
-  @{Esjis::eV}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0C\x0A\x0D])}
+  @{Esjis::eV}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0A\x0B\x0C\x0D])}
   @{Esjis::eR}             qr{(?:\x0D\x0A|[\x0A\x0D])}
   @{Esjis::eN}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0A])}
   @{Esjis::not_alnum}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x5A\x61-\x7A])}
@@ -520,6 +545,7 @@ Esjis::* ֐ Esjis.pm 񋟂܂B
   lcfirst     Esjis::lcfirst    w
   uc          Esjis::uc         w
   ucfirst     Esjis::ucfirst    w
+  fc          Esjis::fc         w
   chr         Esjis::chr        w
   glob        Esjis::glob       w
   lstat       Esjis::lstat      w
@@ -655,8 +681,13 @@ ẘ֐gꍇ͈ȉ̂悤ɋLqKv܂Bꂼ
     $length = Sjis::length($string);
     $length = Sjis::length();
 
-    Sjis::length($string) ̓XJ[l $string ̒ ShiftJIS ̕ŕ
-    ܂B$string ȗꍇ $_ ̕Ԃ܂B
+    Sjis::length($string) ̓XJ[l $string ̒ ShiftJIS ̕(vO
+    }猩镶)ŕԂ܂B$string ȗꍇ $_ ̕Ԃ
+    B
+
+    zAzz(nbV)̑傫m肽ꍇɂ́ASjis::length ͎g
+    Bz̑傫mɂ scalar @arrayAAzzɓĂL[/l̃y
+    Ǎmɂ scalar keys %hash Ƃ܂B
 
     ł͂ȂoCgPʂł̒𒲂ׂɂ́A܂܂Œʂ
 
@@ -701,12 +732,12 @@ ẘ֐gꍇ͈ȉ̂悤ɋLqKv܂Bꂼ
 
 =item * Sjis::index
 
-    $index = Sjis::index($string,$substring,$start);
+    $index = Sjis::index($string,$substring,$offset);
     $index = Sjis::index($string,$substring);
 
     Sjis::index ́AShiftJIS  $string ̒Ɋ܂܂A1 ShiftJIS 
      $substring T܂B$string ̒ŁA$substring ŏɏoʒu
-    PʂŐĕԂ܂B$start w肳ĂꍇA$string ̐擪 $start
+    PʂŐĕԂ܂B$offset w肳ĂꍇA$string ̐擪 $offset
     ̕XLbvʒuA$substring Tn߂܂Bʒu 0 x[XƂ
     Đ܂B$substring Ȃ΁ASjis::index ֐̓x[X 1 
     l -1 Ԃ܂BSjis::index gāAŜ𒲂ׂɂ́Â悤
@@ -720,13 +751,13 @@ ẘ֐gꍇ͈ȉ̂悤ɋLqKv܂Bꂼ
 
 =item * Sjis::rindex
 
-    $rindex = Sjis::rindex($string,$substring,$position);
+    $rindex = Sjis::rindex($string,$substring,$offset);
     $rindex = Sjis::rindex($string,$substring);
 
     Sjis::rindex  Sjis::index ƎĂ܂AShiftJIS  $string ̒ŁA
      $substring Ōɏoʒu𕶎PʂŐĕԂ܂(܂
     reverse Sjis::index ł)B$substring Ȃ΁A-1 Ԃ܂B
-    $position ɂāAlƂĕԂƂAłËʒuw肷邱
+    $offset ɂāAlƂĕԂƂAłËʒuw肷邱
     ł܂BSjis::rindex gāAŜ𖖔擪ɌĒׂ
     ́Â悤ɂ܂B
 
@@ -809,8 +840,8 @@ ẘ֐gꍇ͈ȉ̂悤ɋLqKv܂Bꂼ
     ̐擪̃oCglԂ܂B$expr ȗꂽꍇ $_ ΏۂƂȂ܂B
     ̊֐͏ɕȂ̒lԂ܂B
 
-    t̒lKvł΁Aunpack('C',$expr) g܂B܂SẴoCgl
-    XgƂĕKvł unpack('C',$expr) Ɏg܂B
+    t̒lKvł΁Aunpack('c',$expr) g܂B܂SẴoCgl
+    XgƂĕKvł unpack('C*',$expr) Ɏg܂B
 
 =item * CORE::reverse
 
@@ -825,12 +856,12 @@ ẘ֐gꍇ͈ȉ̂悤ɋLqKv܂Bꂼ
 
 =item * CORE::index
 
-    $index = CORE::index($string,$substring,$start);
+    $index = CORE::index($string,$substring,$offset);
     $index = CORE::index($string,$substring);
 
     CORE::index ́AoCg $string ̒Ɋ܂܂A1̃oCg $substring
     T܂B$string ̒ŁA$substring ŏɏoʒuoCgPʂŐ
-    Ԃ܂B$start w肳ĂꍇA$string ̐擪 $start oCgXLb
+    Ԃ܂B$offset w肳ĂꍇA$string ̐擪 $offset oCgXLb
     vʒuA$substring Tn߂܂Bʒu 0 x[XɂĐ܂B
     $substring Ȃ΁ACORE::index ֐̓x[X 1 l -1
     Ԃ܂BCORE::index gāAoCgŜ𒲂ׂɂ́Â悤ɂ܂B
@@ -843,13 +874,13 @@ ẘ֐gꍇ͈ȉ̂悤ɋLqKv܂Bꂼ
 
 =item * CORE::rindex
 
-    $rindex = CORE::rindex($string,$substring,$position);
+    $rindex = CORE::rindex($string,$substring,$offset);
     $rindex = CORE::rindex($string,$substring);
 
     CORE::rindex  CORE::index ƎĂ܂AoCg $string ̒ŁAoCg
      $substring ŌɏoʒuoCgPʂŐĕԂ܂(܂
     reverse CORE::index ł)B$substring Ȃ΁A-1 Ԃ܂B
-    $position ɂāAlƂĕԂƂAłËʒuw肷邱
+    $offset ɂāAlƂĕԂƂAłËʒuw肷邱
     ł܂BCORE::rindex gāAoCgŜ𖖔擪ɌĒׂ
     ɂ́Â悤ɂ܂B
 
@@ -888,12 +919,6 @@ W[I[o[Ch܂B
 WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;' 
 'use Sjis;' ɏ܂BKvɉĂ̑̏sĂB
 
-=head1 perl5.005 ɂ Perl5.6 G~[V
-
-  perl5.005 ɂ warnings vO}G~[g܂B
-   warnings.pm_  warnings.pm ɁAwarnings/register.pm_ 
-  warnings/register.pm Ƀt@CύXĎgpł܂B
-
 =head1 vO}уW[
 
   -----------------------------------------------------------
@@ -936,6 +961,17 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
   utf8 vO}Abytes vO}̓RgAEg܂Bt@CŒ񋟂
   ֐̑Ƃ Esjis.pm _~[֐񋟂܂B
 
+=head1 perl5.005 ɂ Perl5.6 G~[V
+
+  perl5.005 ɂ warnings vO}G~[g܂B
+   warnings.pm_  warnings.pm ɁAwarnings/register.pm_ 
+  warnings/register.pm Ƀt@CύXĎgpł܂B
+
+=head1 perl5.005 ɂ Perl5.16 G~[V
+
+  perl5.005 ɂ feature vO}G~[g܂B
+   feature.pm_  feature.pm Ƀt@CύXĎgpł܂B
+
 =over 2
 
 =item * _~[̊֐ utf8::upgrade
@@ -1100,6 +1136,11 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
     \G can't treat over 32,767 octets
     http://bugs.activestate.com/show_bug.cgi?id=89792
 
+=item * WJƋɂȂ鐳K\̕ϐ
+
+    ̃eƂ͈قȂAK\ɓWJꂽϐ̒l󕶎ł
+    ĂAOɐK\͎g܂B
+
 =item * ??, m?? ̐
 
     ?? ܂ m?? ̓Ń}`oCgɑ΂ {n,m} {n,} {n} * + Ȃǂ̗ʎw
@@ -1115,11 +1156,6 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
     Ⴆ΁A'ACE' =~ /(?<=[A-Z])([ACE])/ sƃ}b` $1  'C'
     ɂȂ܂A͐܂B
 
-=item * WJƋɂȂ鐳K\̕ϐ
-
-    ̃eƂ͈قȂAK\ɓWJꂽϐ̒l󕶎ł
-    ĂAOɐK\͎g܂B
-
 =item * K\̏Cq /a /d /l /u
 
     ̃\tgEFÃRZvg͕̕𓯎ɗpȂ悤ɂ
@@ -2040,8 +2076,14 @@ cOȂAӂ邷ׂĂ̐lɏƂł܂BƂāA
  http://www.wdic.org/w/WDIC/%E3%82%B7%E3%83%95%E3%83%88JIS
  
  {񏈗sہA܂ăVtgJISقǎpIȕ͂܂B
- ő̗_͂锼pJ^JiƋł邱ƂłBߋ̎Y݂Ɍpł
- ƂƂ́A݂̎Y𖢗֌pł邱ƂĂ܂B
+ ̗R3Ǝv܂B
+ 
+ 1. ̔pJ^Jĩf[^Ƃ̂܂܋łBߋ̎Y݂Ɍpł
+   Ƃ́A݂̎Y𖢗֌pł邱ƂĂ܂B
+ 2. codepoint  grapheme ̒PʂvB̂ŃVXeЂƂƎgЂ
+   ̊Ԃꗂ܂B
+ 3. ̐Lƕ\E󎚏̐LvB̍Hvʐ݌vA[݌vA
+   ɃJ[\̈ړɖ𗧂܂B
  
  1981N̎_ŁA܂ōlĂR̓nbJ[ƌĂԂɂӂ킵ł傤B
 
@@ -2089,10 +2131,11 @@ cOȂAӂ邷ׂĂ̐lɏƂł܂BƂāA
  http://www.fukkan.com/vote.php3?no=4293
  http://www.oreilly.co.jp/books/4873111080/
  
- u{񏈗vǂŕWKiƕwсAɂė[
- ܂܂B̌̂ЂƂƂāup҂̈ӎvƈقȂA̕ϊv
- ܂Bh߂ɁÃ\tgEFA͕ϊɏ񏈗
- s܂B
+ u{񏈗vuCJKV؉z񏈗vǂŕWKiƕwсA
+ ɂė[܂܂B̌̂ЂƂƂāup҂̈ӎvƈ
+ ȂA̕ϊ(sĂ܂)v܂Bh߂ɁA
+ \tgEFA͕ϊɏ񏈗s܂BȂ̈ӎvǂł
+ ƂĂÄӎvƈقȂϊ邱Ƃ͂܂B
  
  Appendix W: Perl Code Examples ̒ CJKV Encoding TemplatesAMultiple-Byte
  AnchoringAMultiple-Byte Processing ƂĂQlɂȂ܂B
@@ -2109,7 +2152,7 @@ cOȂAӂ邷ׂĂ̐lɏƂł܂BƂāA
  http://www.rubyist.net/~matz/slides/yapc2006/
  
  YAPC::Asia 2006 Tokyo "Ruby on Perl(s)" ŁuCSI͕s\ȂvƂ𕪂₷
- Ă炢܂Bx Ruby ł܂̂ł낵肢܂B
+ Ă炢܂Bx Ruby ł邱ƂɂȂA낵肢܂B
 
   av, jperl[U[̂߂
  http://homepage1.nifty.com/kazuf/jperl.html
